@@ -166,7 +166,7 @@ uniqueTypeDec t =
           `AppT` VarT backend, VarT backend2
         ]
             (map (mkUnique backend t) $ entityUniques t)
-            (if null (entityUniques t) then [] else [''Show, ''Read, ''Eq])
+            []
   where
     backend = mkName "backend"
     backend2 = mkName "backend2"
@@ -619,8 +619,14 @@ instance Lift FieldDef where
 instance Lift UniqueDef where
     lift (UniqueDef a b c) = [|UniqueDef $(lift a) $(lift b) $(lift c)|]
 
+pack' :: String -> Text
+pack' = pack
+#if !MIN_VERSION_text(0, 11, 2)
+{-# NOINLINE pack' #-}
+#endif
+
 liftT :: Text -> Q Exp
-liftT t = [|pack $(lift (unpack t))|]
+liftT t = [|pack' $(lift (unpack t))|]
 
 liftTs :: [Text] -> Q Exp
 liftTs = fmap ListE . mapM liftT
